pub struct CxController { /* private fields */ }Expand description
Control handle for a Cx.
Held by the owner of the context to trigger cancellation. Dropping the controller does not cancel the context — cancellation is always explicit.
Implementations
Sourceimpl CxController
impl CxController
Sourcepub fn cancel(&self)
pub fn cancel(&self)
Cancel the associated context.
All clones of the Cx (and children) will observe is_cancelled() == true.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Whether this context has already been cancelled.