pub trait LeafDiff { }Expand description
Marker trait for types that use leaf-level (PartialEq) diffing.
Implement this for primitive types and small value types that should be compared atomically rather than structurally.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".