pub enum KeySequenceAction {
Emit(KeyEvent),
EmitSequence {
kind: KeySequenceKind,
keys: Vec<KeyEvent>,
},
Pending,
}Expand description
Action returned by the key sequence interpreter.
Variants
Emit(KeyEvent)
Emit the key event immediately (no sequence detected).
EmitSequence
A complete key sequence was detected.
Fields

kind: KeySequenceKindThe kind of sequence that was detected.
Pending
Waiting for more keys to complete a potential sequence.
The caller should continue with other work; the interpreter will return the buffered keys if the timeout expires.
Implementations
Sourceimpl KeySequenceAction
impl KeySequenceAction
Sourcepub const fn is_pending(&self) -> bool
pub const fn is_pending(&self) -> bool
Returns true if this action requires the caller to wait for more input.
Sourcepub const fn is_sequence(&self) -> bool
pub const fn is_sequence(&self) -> bool
Returns true if this action emits a sequence.