pub struct Lookup<'a, A> {
pub exact: Option<&'a Binding<A>>,
pub longer: usize,
}Expand description
Result of KeyMap::lookup.
Fields
exact: Option<&'a Binding<A>>The winning binding for exactly this chord, if any.
longer: usizeNumber of applicable bindings whose chord starts with this chord and is longer (a pending prefix must wait for them).
Implementations