pub fn encode_set(
selection: ClipboardSelection,
bytes: &[u8],
) -> Result<Vec<u8>, Osc52Error>Expand description
Encode a clipboard write, rejecting oversized payloads before allocating.
pub fn encode_set(
selection: ClipboardSelection,
bytes: &[u8],
) -> Result<Vec<u8>, Osc52Error>Encode a clipboard write, rejecting oversized payloads before allocating.