pub fn generic_diff<T>(old: &T, new: &T) -> <T::Repr as Diff>::DiffExpand description
Compute a structural diff between two values via their generic representation.
Returns the diff of the representation type, which can be used with
generic_patch to transform old into new.