pub trait LeafDiff { }Expand description
Marker trait for types that use leaf-level (PartialEq) diffing.
Implement this for primitive types and small value types that should be compared atomically rather than structurally.
pub trait LeafDiff { }Marker trait for types that use leaf-level (PartialEq) diffing.
Implement this for primitive types and small value types that should be compared atomically rather than structurally.